function [ncd,CD,M]=get_pz(par);
%returns matrix with formated poles/zeros of CL poles, tracking poles, Hr zeros or Hs zeros 
%suitable for saving in winreg format.
%inputs:
%par... type of required information: par=1 ... CL poles, par=2 ... tracking poles, 
%       par=3 ... Hr zeros, par=4 ... Hs zeros
%outputs:
%ncd ... numbers of complex pairs nC and multiple poles nD: ncd=[nC nD]
%M ... poles characteristics: M=[[ wnat xi ] in the case of complex pair
%                                [ coeff nmult] in the case of multiple real pole  

PREC=1e-8;
M=[];
CD=[];
if (par==1), %CLpoles
   global PD APgama APN PAuxiliary Sypf_den Supf_den Ts;
   %dominant poles
   nC=1; 
   nD=0;
   [m,w,xi]=ddamp(PD,Ts);
   M=[w(1) xi(1)];
   CD='C';
   %filter denominators
   if ~isempty(Sypf_den)& length(Sypf_den)>1,
	   [m,w,xi]=ddamp(Sypf_den,Ts);
      n=round(length(w)/2);
      nC=nC+n;
      for k=1:n, M=[M;[w((k-1)*2+1) xi((k-1)*2+1)]];CD=[CD;'C'];end;
   end;
   if ~isempty(Supf_den)& length(Supf_den)>1,
	   [m,w,xi]=ddamp(Supf_den,Ts);
      n=round(length(w)/2);
      nC=nC+n;
      for k=1:n, M=[M;[w((k-1)*2+1) xi((k-1)*2+1)]];CD=[CD;'C'];end;
   end;
   %aux. poles
   if ~isempty(PAuxiliary),
	   nc=0;
	   nm=0;
      cpx=[];
      cpxcd=[];
      mtr=[];
      mtrcd=[];
      n=length(PAuxiliary);
      for k=1:n,
         if PAuxiliary(k).pair==1, %complex paire
            nc=nc+1;
            cpx=[cpx;[2*pi*PAuxiliary(k).fq_cf PAuxiliary(k).dmp_n]];
            cpxcd=[cpxcd;'C'];
         elseif(PAuxiliary(k).pair==0), %multiple real 
            nm=nm+1;
            mtr=[mtr;[-PAuxiliary(k).fq_cf PAuxiliary(k).dmp_n]];
            mtrcd=[mtrcd;'D'];
         end;
      end;
	   nC=nC+nc;
	   M=[M;cpx];
	   CD=[CD;cpxcd];
      nD=nD+nm;
		M=[M;mtr];
	   CD=[CD;mtrcd];
   end;
   if APN>0, 
      M=[M;[-APgama APN]];
      CD=[CD;'D'];
      nD=nD+1;
   end;
   ncd=[nC nD];
   
elseif(par==2), %tracking poles     
   global Am PD Ts;
   if isempty(Am)|length(Am)==1,%no tracking dymamic => replace by dominant poles
      ncd=[1 0];
      [m,w,xi]=ddamp(PD,Ts);
      M=[w(1) xi(1)];
      CD='C';
   else %tracking model
      [m,w,xi]=ddamp(Am,Ts);
      n=round(length(m)/2);%only pairs are supposed
      ncd=[n 0];
      for k=1:n, M=[M;[w((k-1)*2+1) xi((k-1)*2+1)]];CD=[CD;'C'];end;
   end;
   
elseif(par==3), %Hr zeros
   global Hr Supf_num Ts;
   nC=0;
   nD=0;
   if ~isempty(Supf_num)& length(Supf_num)>1,
	   [m,w,xi]=ddamp(Supf_num,Ts);
      n=round(length(w)/2);
      nC=n;
      for k=1:n, M=[M;[w((k-1)*2+1) xi((k-1)*2+1)]];CD=[CD;'C'];end;
   end;
   if length(Hr)>1,
      Md=[];
      Dd=[];
	   [m,w,xi]=ddamp(Hr,Ts);
	   k=1;
   	while k<=length(w),
	      if abs(xi(k)-1)<PREC | (abs(xi(k)-1)>PREC & abs(m(k)-1)<PREC), %zero rel
            nD=nD+1;   
            if abs(xi(k)-1)<PREC | abs(xi(k)+1)<PREC, %positif real pole
               coeff=-m(k);
            else %negatif real pole
               coeff=m(k);
            end;
            Md=[Md;[coeff 1]];
            Dd=[Dd;'D'];   
	         k=k+1;
	      else %zero copmlexe
	         nC=nC+1;
            M=[M;[w(k) xi(k)]];
            CD=[CD;'C'];
	         k=k+2;
	      end;
	   end;
      M=[M;Md];
      CD=[CD;Dd];
   end;
   ncd=[nC nD];
   
elseif(par==4), %Hs zeros
   global Hs Sypf_num Ts;
   nC=0;
   nD=0;
   if ~isempty(Sypf_num)& length(Sypf_num)>1,
	   [m,w,xi]=ddamp(Sypf_num,Ts);
      n=round(length(w)/2);
      nC=n;
      for k=1:n, M=[M;[w((k-1)*2+1) xi((k-1)*2+1)]];CD=[CD;'C'];end;
   end;
   if length(Hs)>1,
      Md=[];
      Dd=[];
	   [m,w,xi]=ddamp(Hs,Ts);
	   k=1;
	   while k<=length(w),
	      if abs(abs(xi(k))-1)<PREC, %zero rel
            if abs(m(k)-1)>PREC, %not integrator
               nD=nD+1;
               if abs(xi(k)-1)<PREC | abs(xi(k)+1)<PREC, %positif real pole
                  coeff=-m(k);
               else %negatif real pole
                  coeff=m(k);
               end;
               Md=[Md;[coeff 1]];
               Dd=[Dd;'D'];
            end; 
	         k=k+1;
	      else %zero copmlexe
	         nC=nC+1;
            M=[M;[w(k) xi(k)]];
            CD=[CD;'C'];
	         k=k+2;
	      end;
	   end;
      M=[M;Md];
      CD=[CD;Dd];
   end;
   ncd=[nC nD];
   
end;

   
   
